@@ -20,7 +20,7 @@ from ethtx.decoders.semantic.helpers.utils import (
     semantically_decode_parameter,
     get_badge,
 )
-from ethtx.models.decoded_model import DecodedEvent, DecodedTransactionMetadata
+from ethtx.models.decoded_model import DecodedEvent, DecodedTransactionMetadata, Proxy
 from ethtx.semantics.protocols.anonymous import anonymous_events
 from ethtx.semantics.standards.erc20 import ERC20_EVENTS, ERC20_TRANSFORMATIONS
 from ethtx.semantics.standards.erc721 import ERC721_TRANSFORMATIONS, ERC721_EVENTS
@@ -36,33 +36,30 @@ class SemanticEventsDecoder(SemanticSubmoduleAbc):
         self,
         events: Union[DecodedEvent, List[DecodedEvent]],
         tx_metadata: DecodedTransactionMetadata,
-        token_proxies: Dict[str, Dict],
+        proxies: Dict[str, Proxy],
     ) -> Union[DecodedEvent, List[DecodedEvent]]:
         """Semantically decode events."""
         if isinstance(events, list):
             return (
-                [
-                    self.decode_event(event, tx_metadata, token_proxies)
-                    for event in events
-                ]
+                [self.decode_event(event, tx_metadata, proxies) for event in events]
                 if events
                 else []
             )
 
-        return self.decode_event(events, tx_metadata, token_proxies)
+        return self.decode_event(events, tx_metadata, proxies)
 
     def decode_event(
         self,
         event: DecodedEvent,
         tx_metadata: DecodedTransactionMetadata,
-        token_proxies: Dict[str, Dict],
+        proxies: Dict[str, Proxy],
     ) -> DecodedEvent:
         """Semantically decode event"""
 
         def _get_parameters_str(parameters):
             parameters_types = []
             for parameter in parameters:
-                if parameter.type == 'tuple':
+                if parameter.type == "tuple":
                     parameters_types.append(_get_parameters_str(parameter.value))
                 else:
                     parameters_types.append(parameter.type)
@@ -72,7 +69,7 @@ class SemanticEventsDecoder(SemanticSubmoduleAbc):
             # calculate signature to account for anonymous events
             parameters_str = _get_parameters_str(event.parameters)
             calculated_event_signature = Web3.keccak(
-                text=f'{event.event_name}{parameters_str}'
+                text=f"{event.event_name}{parameters_str}"
             ).hex()
         else:
             calculated_event_signature = event.event_signature
@@ -102,15 +99,19 @@ class SemanticEventsDecoder(SemanticSubmoduleAbc):
             ):
                 event_transformations = anonymous_events[calculated_event_signature]
             else:
-                event_transformations = dict()
+                event_transformations = {}
 
         # prepare context for transformations
         context = create_transformation_context(
             event.contract.address, event.parameters, [], tx_metadata, self.repository
         )
         standard = self.repository.get_standard(event.chain_id, event.contract.address)
-        if not standard and event.contract.address in token_proxies:
-            standard = token_proxies[event.contract.address][3]
+        if (
+            not standard
+            and event.contract.address in proxies
+            and proxies[event.contract.address].token
+        ):
+            standard = "ERC20"
 
         # perform parameters transformation
         for i, parameter in enumerate(event.parameters):
@@ -119,7 +120,7 @@ class SemanticEventsDecoder(SemanticSubmoduleAbc):
                 parameter,
                 f"__input{i}__",
                 event_transformations,
-                token_proxies,
+                proxies,
                 context,
             )
 
@@ -137,7 +138,7 @@ class SemanticEventsDecoder(SemanticSubmoduleAbc):
                             parameter,
                             f"__input{i}__",
                             event_transformations,
-                            token_proxies,
+                            proxies,
                             context,
                         )
         elif standard == "ERC721":
@@ -156,7 +157,7 @@ class SemanticEventsDecoder(SemanticSubmoduleAbc):
                             parameter,
                             f"__input{i}__",
                             event_transformations,
-                            token_proxies,
+                            proxies,
                             context,
                         )
 
